robotpy-rev
===========

This is a python wrapper around the REV Spark MAX API. The RobotPy project
is not associated with or endorsed by REV Robotics.

**WARNING**: These bindings are still a work in progress, and some things
may not work quite right yet. Please try them out and let us know how
it goes!

Documentation
=============

* `Installation <http://robotpy.readthedocs.io/en/stable/install/rev.html>`_
* `Python API Documentation <http://robotpy.readthedocs.io/projects/rev/en/stable/api.html>`_
* `REV's SparkMAX software <https://www.revrobotics.com/sparkmax-software/>`_


Developers Notes
================

Notes for advanced users and developers can be found in develop.md in the git
repository.

License
=======

RobotPy specific bits are available under the Apache 2.0 license. The REV
specific pieces are available under a BSD license.

Author
======

Dustin Spicuzza (dustin@virtualroadside.com)
